pub struct SafeContractRunner { /* private fields */ }Expand description
Safe-backed contract runner using safe-rs.
This currently targets single-owner (1/1 threshold) Safes, matching the current capabilities of the underlying Safe crate used here.
Implementations
Sourceimpl SafeContractRunner
impl SafeContractRunner
Sourcepub async fn connect(
rpc_url: &str,
private_key: &str,
safe_address: Address,
) -> Result<Self, RunnerError>
pub async fn connect( rpc_url: &str, private_key: &str, safe_address: Address, ) -> Result<Self, RunnerError>
Connect to an existing Safe using the given RPC URL, signer private key, and Safe address.
Sourcepub async fn prepare_transactions(
&self,
txs: Vec<PreparedTransaction>,
) -> Result<PreparedSafeExecution, RunnerError>
pub async fn prepare_transactions( &self, txs: Vec<PreparedTransaction>, ) -> Result<PreparedSafeExecution, RunnerError>
Prepare the canonical Safe payload/hash for one or more SDK transactions without executing them immediately.